@@ -21,8 +21,8 @@
 #define ACCOUNTMODEL_H
 
 #include "user_manager_debug.h"
-#include <QtCore/QStringList>
-#include <QtCore/QAbstractListModel>
+#include <QStringList>
+#include <QAbstractListModel>
 #include <QDBusObjectPath>
 #include <QDBusPendingReply>
 #include <KEMailSettings>
@@ -58,12 +58,12 @@ class AccountModel : public QAbstractListModel
         };
 
         explicit AccountModel(QObject* parent);
-        ~AccountModel() Q_DECL_OVERRIDE;
-        int rowCount(const QModelIndex& parent = QModelIndex()) const Q_DECL_OVERRIDE;
-        QVariant data(const QModelIndex& index, int role) const Q_DECL_OVERRIDE;
-        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-        bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) Q_DECL_OVERRIDE;
-        bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex()) Q_DECL_OVERRIDE;
+        ~AccountModel() override;
+        int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+        QVariant data(const QModelIndex& index, int role) const override;
+        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+        bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) override;
+        bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex()) override;
         bool removeAccountKeepingFiles(int row, bool keepFile = false);
 
         QVariant newUserData(int role) const;
